@@ -10,9 +10,9 @@
 
 #include <KLocalizedString>
 
-#include <KPackage/PackageStructure>
 #include <KPackage/Package>
 #include <KPackage/PackageLoader>
+#include <KPackage/PackageStructure>
 
 #include <QCoreApplication>
 #include <QRunnable>
@@ -29,16 +29,19 @@ enum Operation {
     UninstallOperation,
 };
 class KPackageTask;
-class KPackageJob::Private {
+class KNSCore::KPackageJobPrivate
+{
 public:
-    Private() {}
+    KPackageJobPrivate()
+    {
+    }
 
     QString package;
     QString packageRoot;
     QString serviceType;
     Operation operation{UnknownOperation};
 
-    KPackageTask* runnable{nullptr};
+    KPackageTask *runnable{nullptr};
 };
 
 class KPackageTask : public QObject, public QRunnable
@@ -50,7 +53,7 @@ public:
     QString serviceType;
     Operation operation{UnknownOperation};
 
-    explicit KPackageTask(QObject* parent = nullptr)
+    explicit KPackageTask(QObject *parent = nullptr)
         : QObject(parent)
         , QRunnable()
     {
@@ -59,22 +62,23 @@ public:
         // As this has to be set before QThreadPool runs things, we need to do so here
         setAutoDelete(false);
     };
-    virtual ~KPackageTask() {}
+    ~KPackageTask() override
+    {
+    }
     void run() override
     {
-        qCDebug(KNEWSTUFFCORE) << "Attempting to perform an installation operation of type" << operation << "on the package" << package << "of type" << serviceType << "in the package root" << packageRoot;
+        qCDebug(KNEWSTUFFCORE) << "Attempting to perform an installation operation of type" << operation << "on the package" << package << "of type"
+                               << serviceType << "in the package root" << packageRoot;
         int errorlevel{0};
         QString errordescription;
-        structure.reset(KPackage::PackageLoader::self()->loadPackageStructure(serviceType));
+        // PackageStructure instances are managed internally by KPackage, never delete them
+        KPackage::PackageStructure *structure = KPackage::PackageLoader::self()->loadPackageStructure(serviceType);
         if (structure) {
             qCDebug(KNEWSTUFFCORE) << "Service type understood";
-            // Ensure we clear the pointer if the structure's deleted (for some reason)
-            connect(structure.get(), &QObject::destroyed, this, [this](){ structure.take(); });
-            installer.reset(new KPackage::Package(structure.data()));
+            installer.reset(new KPackage::Package(structure));
             if (installer->hasValidStructure()) {
                 qCDebug(KNEWSTUFFCORE) << "Installer successfully created and has a valid structure";
-                switch(operation)
-                {
+                switch (operation) {
                 case InstallOperation:
                     job.reset(installer->install(package, packageRoot));
                     break;
@@ -94,18 +98,27 @@ public:
                     qCDebug(KNEWSTUFFCORE) << "Created job, now let's wait for it to do its thing...";
                     job->setAutoDelete(false);
                     QEventLoop loop;
-                    connect(job.get(), &KJob::result, this, [&loop,&errordescription](KJob* job){
-                        errordescription = job->errorText();
-                        loop.exit(job->error());
-                    }, Qt::BlockingQueuedConnection);
+                    connect(
+                        job.get(),
+                        &KJob::result,
+                        this,
+                        [&loop, &errordescription](KJob *job) { // clazy:exclude=lambda-in-connect
+                            errordescription = job->errorText();
+                            loop.exit(job->error());
+                        },
+                        Qt::BlockingQueuedConnection);
                     errorlevel = loop.exec();
                 } else {
                     errorlevel = 3;
-                    errordescription = i18n("Failed to create a job for the package management task. This is usually because the package is invalid. We attempted to operate on the package %1", package);
+                    errordescription = i18n(
+                        "Failed to create a job for the package management task. This is usually because the package is invalid. We attempted to operate on "
+                        "the package %1",
+                        package);
                 }
             } else {
                 errorlevel = 2;
-                errordescription = i18n("Could not create a package installer for the service type %1: The installer does not have a valid structure", serviceType);
+                errordescription =
+                    i18n("Could not create a package installer for the service type %1: The installer does not have a valid structure", serviceType);
             }
         } else {
             errorlevel = 1;
@@ -117,23 +130,20 @@ public:
         Q_EMIT result();
     }
     Q_SIGNAL void result();
-    Q_SIGNAL void error(int errorCode, const QString& errorText);
+    Q_SIGNAL void error(int errorCode, const QString &errorText);
+
 private:
-    QScopedPointer<KPackage::PackageStructure> structure;
     QScopedPointer<KPackage::Package> installer;
     QScopedPointer<KJob> job;
 };
 
-KPackageJob::KPackageJob(QObject* parent)
+KPackageJob::KPackageJob(QObject *parent)
     : KJob(parent)
-    , d(new Private)
+    , d(new KPackageJobPrivate)
 {
 }
 
-KPackageJob::~KPackageJob()
-{
-    delete d;
-}
+KPackageJob::~KPackageJob() = default;
 
 void KPackageJob::start()
 {
@@ -146,17 +156,29 @@ void KPackageJob::start()
     d->runnable->packageRoot = d->packageRoot;
     d->runnable->serviceType = d->serviceType;
     d->runnable->operation = d->operation;
-    connect(d->runnable, &KPackageTask::error, this, [this](int errorCode, const QString& errorText){
-        setError(errorCode);
-        setErrorText(errorText);
-    }, Qt::QueuedConnection);
-    connect(d->runnable, &KPackageTask::result, this, [this](){ emitResult(); }, Qt::QueuedConnection);
+    connect(
+        d->runnable,
+        &KPackageTask::error,
+        this,
+        [this](int errorCode, const QString &errorText) {
+            setError(errorCode);
+            setErrorText(errorText);
+        },
+        Qt::QueuedConnection);
+    connect(
+        d->runnable,
+        &KPackageTask::result,
+        this,
+        [this]() {
+            emitResult();
+        },
+        Qt::QueuedConnection);
     QThreadPool::globalInstance()->start(d->runnable);
 }
 
-KNSCore::KPackageJob * KNSCore::KPackageJob::install(const QString &sourcePackage, const QString &packageRoot, const QString &serviceType)
+KNSCore::KPackageJob *KNSCore::KPackageJob::install(const QString &sourcePackage, const QString &packageRoot, const QString &serviceType)
 {
-    KPackageJob* job = new KPackageJob();
+    KPackageJob *job = new KPackageJob();
     job->d->package = sourcePackage;
     job->d->packageRoot = packageRoot;
     job->d->serviceType = serviceType;
@@ -165,9 +187,9 @@ KNSCore::KPackageJob * KNSCore::KPackageJob::install(const QString &sourcePackag
     return job;
 }
 
-KPackageJob * KPackageJob::update(const QString &sourcePackage, const QString &packageRoot, const QString &serviceType)
+KPackageJob *KPackageJob::update(const QString &sourcePackage, const QString &packageRoot, const QString &serviceType)
 {
-    KPackageJob* job = new KPackageJob();
+    KPackageJob *job = new KPackageJob();
     job->d->package = sourcePackage;
     job->d->packageRoot = packageRoot;
     job->d->serviceType = serviceType;
@@ -176,9 +198,9 @@ KPackageJob * KPackageJob::update(const QString &sourcePackage, const QString &p
     return job;
 }
 
-KPackageJob * KPackageJob::uninstall(const QString &packageName, const QString &packageRoot, const QString &serviceType)
+KPackageJob *KPackageJob::uninstall(const QString &packageName, const QString &packageRoot, const QString &serviceType)
 {
-    KPackageJob* job = new KPackageJob();
+    KPackageJob *job = new KPackageJob();
     job->d->package = packageName;
     job->d->packageRoot = packageRoot;
     job->d->serviceType = serviceType;
