@@ -1,27 +1,16 @@
 /*
     This file is part of KNewStuff2.
-    Copyright (c) 2004, 2005 Andras Mantia <amantia@kde.org>
-    Copyright (c) 2007 Josef Spillner <spillner@kde.org>
+    SPDX-FileCopyrightText: 2004, 2005 Andras Mantia <amantia@kde.org>
+    SPDX-FileCopyrightText: 2007 Josef Spillner <spillner@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-//app includes
+// app includes
 #include "security.h"
 #include "question.h"
 
-//qt includes
+// qt includes
 #include <QFile>
 #include <QFileInfo>
 #include <QStringList>
@@ -31,11 +20,12 @@
 
 #include <QCryptographicHash>
 
-//kde includes
-#include <klocalizedstring.h>
+// kde includes
+#include <KLocalizedString>
 
 using namespace KNSCore;
 
+#if KNEWSTUFFCORE_BUILD_DEPRECATED_SINCE(5, 31)
 static QString gpgExecutable()
 {
     QString gpgExe = QStandardPaths::findExecutable(QStringLiteral("gpg"));
@@ -63,24 +53,21 @@ Security::~Security()
 void Security::readKeys()
 {
     if (m_gpgRunning) {
-        QTimer::singleShot(5, this, SLOT(readKeys()));
+        QTimer::singleShot(5, this, &Security::readKeys);
         return;
     }
     m_runMode = List;
     m_keys.clear();
     m_process = new QProcess();
     QStringList arguments;
-    arguments << QStringLiteral("--no-secmem-warning")
-              << QStringLiteral("--no-tty")
-              << QStringLiteral("--with-colon")
-              << QStringLiteral("--list-keys");
-    connect(m_process, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished),
-            this, &Security::slotFinished);
-    connect(m_process, &QProcess::readyReadStandardOutput,
-            this, &Security::slotReadyReadStandardOutput);
+    arguments << QStringLiteral("--no-secmem-warning") << QStringLiteral("--no-tty") << QStringLiteral("--with-colon") << QStringLiteral("--list-keys");
+    connect(m_process, &QProcess::finished, this, &Security::slotFinished);
+    connect(m_process, &QProcess::readyReadStandardOutput, this, &Security::slotReadyReadStandardOutput);
     m_process->start(gpgExecutable(), arguments);
     if (!m_process->waitForStarted()) {
-        emit signalError(i18n("<qt>Cannot start <i>gpg</i> and retrieve the available keys. Make sure that <i>gpg</i> is installed, otherwise verification of downloaded resources will not be possible.</qt>"));
+        Q_EMIT signalError(
+            i18n("<qt>Cannot start <i>gpg</i> and retrieve the available keys. Make sure that <i>gpg</i> is installed, otherwise verification of downloaded "
+                 "resources will not be possible.</qt>"));
         delete m_process;
         m_process = nullptr;
     } else {
@@ -91,20 +78,15 @@ void Security::readKeys()
 void Security::readSecretKeys()
 {
     if (m_gpgRunning) {
-        QTimer::singleShot(5, this, SLOT(readSecretKeys()));
+        QTimer::singleShot(5, this, &Security::readSecretKeys);
         return;
     }
     m_runMode = ListSecret;
     m_process = new QProcess();
     QStringList arguments;
-    arguments << QStringLiteral("--no-secmem-warning")
-              << QStringLiteral("--no-tty")
-              << QStringLiteral("--with-colon")
-              << QStringLiteral("--list-secret-keys");
-    connect(m_process, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished),
-            this, &Security::slotFinished);
-    connect(m_process, &QProcess::readyReadStandardOutput,
-            this, &Security::slotReadyReadStandardOutput);
+    arguments << QStringLiteral("--no-secmem-warning") << QStringLiteral("--no-tty") << QStringLiteral("--with-colon") << QStringLiteral("--list-secret-keys");
+    connect(m_process, &QProcess::finished, this, &Security::slotFinished);
+    connect(m_process, &QProcess::readyReadStandardOutput, this, &Security::slotReadyReadStandardOutput);
     m_process->start(gpgExecutable(), arguments);
     if (!m_process->waitForStarted()) {
         delete m_process;
@@ -126,11 +108,12 @@ void Security::slotFinished(int exitCode, QProcess::ExitStatus exitStatus)
     case ListSecret:
         m_keysRead = true;
         break;
-    case Verify: emit validityResult(m_result);
+    case Verify:
+        Q_EMIT validityResult(m_result);
         break;
-    case Sign:   emit fileSigned(m_result);
+    case Sign:
+        Q_EMIT fileSigned(m_result);
         break;
-
     }
     m_gpgRunning = false;
     delete m_process;
@@ -154,11 +137,7 @@ void Security::slotReadyReadStandardOutput()
                 } else {
                     key.secret = true;
                 }
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-                QStringList line = data.split(QLatin1Char(':'), QString::KeepEmptyParts);
-#else
                 QStringList line = data.split(QLatin1Char(':'), Qt::KeepEmptyParts);
-#endif
                 key.id = line[4];
                 QString shortId = key.id.right(8);
                 QString trustStr = line[1];
@@ -208,8 +187,9 @@ void Security::slotReadyReadStandardOutput()
             if (data.contains(QLatin1String("passphrase.enter"))) {
                 KeyStruct key = m_keys[m_secretKey];
                 Question question(Question::PasswordQuestion);
-                question.setQuestion(i18n("<qt>Enter passphrase for key <b>0x%1</b>, belonging to<br /><i>%2&lt;%3&gt;</i><br />:</qt>", m_secretKey, key.name, key.mail));
-                if(question.ask() == Question::ContinueResponse) {
+                question.setQuestion(
+                    i18n("<qt>Enter passphrase for key <b>0x%1</b>, belonging to<br /><i>%2&lt;%3&gt;</i><br />:</qt>", m_secretKey, key.name, key.mail));
+                if (question.ask() == Question::ContinueResponse) {
                     m_process->write(question.response().toLocal8Bit() + '\n');
                 } else {
                     m_result |= BAD_PASSPHRASE;
@@ -233,18 +213,18 @@ void Security::checkValidity(const QString &filename)
 void Security::slotCheckValidity()
 {
     if (!m_keysRead || m_gpgRunning) {
-        QTimer::singleShot(5, this, SLOT(slotCheckValidity()));
+        QTimer::singleShot(5, this, &Security::slotCheckValidity);
         return;
     }
     if (m_keys.isEmpty()) {
-        emit validityResult(-1);
+        Q_EMIT validityResult(-1);
         return;
     }
 
     m_result = 0;
     m_runMode = Verify;
     QFileInfo f(m_fileName);
-    //check the MD5 sum
+    // check the MD5 sum
     QString md5sum;
     QCryptographicHash context(QCryptographicHash::Md5);
     QFile file(m_fileName);
@@ -269,25 +249,21 @@ void Security::slotCheckValidity()
     m_signatureKey.mail = QLatin1String("");
     m_signatureKey.trusted = false;
 
-    //verify the signature
+    // verify the signature
     m_process = new QProcess();
     QStringList arguments;
-    arguments << QStringLiteral("--no-secmem-warning")
-              << QStringLiteral("--status-fd=2")
-              << QStringLiteral("--command-fd=0")
-              << QStringLiteral("--verify")
-              << f.path() + QStringLiteral("/signature")
-              << m_fileName;
-    connect(m_process, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished),
-            this, &Security::slotFinished);
-    connect(m_process, &QProcess::readyReadStandardOutput,
-            this, &Security::slotReadyReadStandardOutput);
+    arguments << QStringLiteral("--no-secmem-warning") << QStringLiteral("--status-fd=2") << QStringLiteral("--command-fd=0") << QStringLiteral("--verify")
+              << f.path() + QStringLiteral("/signature") << m_fileName;
+    connect(m_process, &QProcess::finished, this, &Security::slotFinished);
+    connect(m_process, &QProcess::readyReadStandardOutput, this, &Security::slotReadyReadStandardOutput);
     m_process->start(gpgExecutable(), arguments);
     if (m_process->waitForStarted()) {
         m_gpgRunning = true;
     } else {
-        emit signalError(i18n("<qt>Cannot start <i>gpg</i> and check the validity of the file. Make sure that <i>gpg</i> is installed, otherwise verification of downloaded resources will not be possible.</qt>"));
-        emit validityResult(0);
+        Q_EMIT signalError(
+            i18n("<qt>Cannot start <i>gpg</i> and check the validity of the file. Make sure that <i>gpg</i> is installed, otherwise verification of downloaded "
+                 "resources will not be possible.</qt>"));
+        Q_EMIT validityResult(0);
         delete m_process;
         m_process = nullptr;
     }
@@ -302,7 +278,7 @@ void Security::signFile(const QString &fileName)
 void Security::slotSignFile()
 {
     if (!m_keysRead || m_gpgRunning) {
-        QTimer::singleShot(5, this, SLOT(slotSignFile()));
+        QTimer::singleShot(5, this, &Security::slotSignFile);
         return;
     }
 
@@ -314,14 +290,14 @@ void Security::slotSignFile()
     }
 
     if (secretKeys.isEmpty()) {
-        emit fileSigned(-1);
+        Q_EMIT fileSigned(-1);
         return;
     }
 
     m_result = 0;
     QFileInfo f(m_fileName);
 
-    //create the MD5 sum
+    // create the MD5 sum
     QString md5sum;
     QCryptographicHash context(QCryptographicHash::Md5);
     QFile file(m_fileName);
@@ -344,43 +320,36 @@ void Security::slotSignFile()
         question.setQuestion(i18n("Key used for signing:"));
         question.setTitle(i18n("Select Signing Key"));
         question.setList(secretKeys);
-        if(question.ask() == Question::OKResponse) {
+        if (question.ask() == Question::OKResponse) {
             m_secretKey = question.response();
         } else {
             // emit an error to be forwarded to the user for selecting a signing key...
-            emit fileSigned(0);
+            Q_EMIT fileSigned(0);
             return;
         }
     } else {
         m_secretKey = secretKeys[0];
     }
 
-    //verify the signature
+    // verify the signature
     m_process = new QProcess();
     QStringList arguments;
-    arguments << QStringLiteral("--no-secmem-warning")
-              << QStringLiteral("--status-fd=2")
-              << QStringLiteral("--command-fd=0")
-              << QStringLiteral("--no-tty")
-              << QStringLiteral("--detach-sign")
-              << QStringLiteral("-u")
-              << m_secretKey
-              << QStringLiteral("-o")
-              << f.path() + QStringLiteral("/signature")
+    arguments << QStringLiteral("--no-secmem-warning") << QStringLiteral("--status-fd=2") << QStringLiteral("--command-fd=0") << QStringLiteral("--no-tty")
+              << QStringLiteral("--detach-sign") << QStringLiteral("-u") << m_secretKey << QStringLiteral("-o") << f.path() + QStringLiteral("/signature")
               << m_fileName;
-    connect(m_process, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished),
-            this, &Security::slotFinished);
-    connect(m_process, &QProcess::readyReadStandardOutput,
-            this, &Security::slotReadyReadStandardOutput);
+    connect(m_process, &QProcess::finished, this, &Security::slotFinished);
+    connect(m_process, &QProcess::readyReadStandardOutput, this, &Security::slotReadyReadStandardOutput);
     m_runMode = Sign;
     m_process->start(gpgExecutable(), arguments);
     if (m_process->waitForStarted()) {
         m_gpgRunning = true;
     } else {
-        emit signalError(i18n("<qt>Cannot start <i>gpg</i> and sign the file. Make sure that <i>gpg</i> is installed, otherwise signing of the resources will not be possible.</qt>"));
-        emit fileSigned(0);
+        Q_EMIT signalError(
+            i18n("<qt>Cannot start <i>gpg</i> and sign the file. Make sure that <i>gpg</i> is installed, otherwise signing of the resources will not be "
+                 "possible.</qt>"));
+        Q_EMIT fileSigned(0);
         delete m_process;
         m_process = nullptr;
     }
 }
-
+#endif
